#
# spec file for package epiphany-branding-openSUSE
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define epiphany_version %(rpm -q --qf '%%{version}' epiphany)
Name:           epiphany-branding-openSUSE
Version:        %{epiphany_version}
Release:        1.17
Summary:        GNOME Web Browser -- openSUSE default bookmarks and user agent string
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Web/Browsers
URL:            http://www.gnome.org/projects/epiphany/
Source0:        COPYING
Source1:        branding.conf.in
# PATCH-FEATURE-OPENSUSE opensuse-bookmarks.patch vuntz@novell.com -- Add openSUSE bookmarks
Patch0:         opensuse-bookmarks.patch
BuildRequires:  epiphany >= 3.23.2
# To be in sync with upstream defaults, do branding as a patch for upstream file.
# WARNING: As this package conflicts with epiphany-branding-openSUSE, you cannot
#          reuse build root. You have to build in a clean build root every time!
BuildRequires:  epiphany-branding-upstream >= 3.11.2
Requires:       epiphany = %{epiphany_version}
Supplements:    (epiphany and branding-openSUSE)
Conflicts:      epiphany-branding
Provides:       epiphany-branding = %{epiphany_version}
BuildArch:      noarch

%description
Epiphany is a Web Browser for the GNOME Desktop. Its principles are
simplicity and standards compliance.

This package provides the openSUSE default bookmarks and user
agent string.

%prep
cp -a %{_datadir}/epiphany/default-bookmarks.rdf .
%patch -P 0
cp -a %{SOURCE0} .

%build
case "%{?suse_version}" in
  1330)
	DISTRO="Tumbleweed"
	;;
  1320)
	DISTRO="13.2"
	;;
  1315)
%if 0%{?is_opensuse}
	DISTRO="Leap 42.1"
%else
	DISTRO="SLE12"
%endif
	;;
  1310)
	DISTRO="13.1"
	;;
  *)
	DISTRO="undef"
	;;
esac
sed "s,@distroversion@,$DISTRO,g;s,@pkgversion@,%{epiphany_version},g" %{SOURCE1} > branding.conf

%install
# custom bookmarks
install -D -m0644 default-bookmarks.rdf %{buildroot}%{_datadir}/epiphany/default-bookmarks.rdf
# user agent
install -D -m0644 branding.conf %{buildroot}%{_datadir}/epiphany/branding.conf

%files
%license COPYING

%{_datadir}/epiphany/default-bookmarks.rdf
%{_datadir}/epiphany/branding.conf

%changelog
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update version to match epiphany.
* Tue Nov 28 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -p N instead of deprecated %%patchN.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Dec  5 2016 dimstar@opensuse.org
- Rebase opensuse-bookmarks.patch for epiphany 3.23.2.
* Mon Dec  5 2016 fcrozat@suse.com
- Fix is_opensuse macro usage.
* Mon May  9 2016 zaitor@opensuse.org
- Rebase opensuse-bookmarks.patch to fit with what epiphany now
  ships in the stable release.
* Mon May  2 2016 zaitor@opensuse.org
- Drop epiphany-branding-SLED subpackage:
  + Remove sled-bookmarks.patch, pre_checkin.sh,
    epiphany-branding-SLED.changes, epiphany-branding.changes.in
    and epiphany-branding-SLED.spec.
  + Clean epiphany-branding-openSUSE.spec for all references to the
    previous package.
* Fri Feb 12 2016 dimstar@opensuse.org
- Patch tagging: use valid tags.
* Fri Jan 22 2016 dimstar@opensuse.org
- Make build not rely on lsb and opensuse-release (no constant
  rebuild in Tumbleweed):
  + Drop lsb/lsb-release BuildRequires.
  + Drop opensuse-release BuildRequires.
  + Use %%{suse_version} in build section to inject proper values
    into branding.conf. On Tumbleweed we no longer use the snapshot
    version (which is anyway useless) but simply inject
    'Tumbleweed'. We currently detect openSUSE 13.1, 13.2,
    Leap 42.1, SLE12 and Tumbleweed systems. All others will have
    'SUSE/undef' in the browsers user agent string.
* Mon Oct 12 2015 zaitor@opensuse.org
- Bump version to 42.1, to prepare for next version of openSUSE.
* Thu Apr  3 2014 dimstar@opensuse.org
- Bump version to 13.2, to prepare for next version of openSUSE.
* Sun Jan 19 2014 dimstar@opensuse.org
- Rebase opensuse-bookmarks.patch and sled-bookmarks.patch for
  Epiphany 3.11.3.
* Mon Dec 23 2013 dimstar@opensuse.org
- Rebase opensuse-bookmarks.patch and sled-bookmarks.patch for
  Epiphany 3.11.2.
- Update COPYING based on latest published GPL-2.0 text:
  http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt.
* Sun Sep  8 2013 zaitor@opensuse.org
- Bump version to 13.1, to prepare for next version of openSUSE.
* Sat Sep  7 2013 dimstar@opensuse.org
- Rebase opensuse-bookmarks.patch and sled-bookmarks.patch against
  epiphany 3.9.90.
* Wed May 23 2012 vuntz@opensuse.org
- Bump version to 12.2, to prepare for next version of openSUSE.
* Wed May  2 2012 dimstar@opensuse.org
- Add "GNOME Shell extensions" (https://extensions.gnome.org) to
  openSUSE bookmarks.
* Thu Oct 13 2011 vuntz@opensuse.org
- Remove %%{release} from the epiphany versioned Requires, to not
  have to rebuild this package each time epiphany rebuilds to keep
  it installable.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
* Wed Jul  6 2011 vuntz@opensuse.org
- Bump version to 12.1.
- Add a Requires for epiphany, since the branding package is
  useless without it.
- Update summary and description.
- Add Url tag.
* Sun Jan  9 2011 vuntz@opensuse.org
- Update the Planet bookmark to point to Planet openSUSE.
* Fri Oct  8 2010 vuntz@opensuse.org
- Bump version to 11.4.
* Fri Jan 15 2010 vuntz@opensuse.org
- Merge openSUSE and SLED branding packaging, and generate the
  packages from the same sources.
- Change version to 11.3.
- Add COPYING file.
- Add branding.conf.in: with a recent epiphany, we can change the
  user agent with a simple file.
- Add BuildRequires on lsb-release and suse-release to get the
  version of the distribution, to put in the user agent.
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Thu Aug 13 2009 vuntz@novell.com
- Respin opensuse-bookmarks.patch to apply to latest epiphany.
* Mon Aug  3 2009 vuntz@novell.com
- Update for epiphany webkit change: the user agent isn't set here
  anymore (it's set in gconf2-branding).
- Bump version to 11.2.
* Tue Nov  4 2008 vuntz@novell.com
- Bump version to 11.1. Part of bnc#440849.
* Mon Oct  6 2008 sbrabec@suse.cz
- Conflict with other branding providers (FATE#304881).
* Thu Sep 11 2008 vuntz@novell.com
- Add more openSUSE bookmarks.
- Clean up spec file.
* Tue Jul 29 2008 vuntz@novell.com
- New package.
- Add openSUSE documentation bookmark. (fate#305003)
